field_attributes — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# field_attributes

Field types handled through introspection :

Field type | Default delegate | Default editor
BOOLEAN | BoolDelegate |
Boolean | BoolDelegate |
Code | CodeDelegate |
Color | ColorDelegate |
Date | DateDelegate |
DateTime | DateTimeDelegate |
Enumeration | EnumerationDelegate |
File | FileDelegate |
Float | FloatDelegate |
INTEGER | IntegerDelegate |
IPAddress | CodeDelegate |
Image | ImageDelegate |
Integer | IntegerDelegate |
Language | LanguageDelegate |
Numeric | FloatDelegate |
Rating | StarDelegate |
RichText | RichTextDelegate |
String | PlainTextDelegate |
TEXT | PlainTextDelegate |
Time | TimeDelegate |
Unicode | PlainTextDelegate |
VirtualAddress | VirtualAddressDelegate |

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus